@@ -4,6 +4,7 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Optional
 
+from requests.exceptions import ConnectionError as RequestConnectionError
 from requests.exceptions import HTTPError, SSLError, Timeout
 
 from robotoff.insights.dataclass import InsightType
@@ -118,15 +119,16 @@ class InsightAnnotator(metaclass=abc.ABCMeta):
                 )
             except HTTPError as e:
                 if e.response.status_code >= 500:
-                    logger.info("HTTPError occurred during OFF update: %s", e)
+                    logger.info(
+                        "HTTPError occurred during OFF update: %s",
+                        e.response.status_code,
+                    )
                     logger.info("Rolling back SQL transaction")
                     tx.rollback()
                     return FAILED_UPDATE_RESULT
                 raise e
-            except (Timeout, SSLError) as e:
-                logger.info(
-                    "Error occurred during OFF update: %s, %s", type(e).__name__, e
-                )
+            except (RequestConnectionError, Timeout, SSLError) as e:
+                logger.info("Error occurred during OFF update", exc_info=e)
                 logger.info("Rolling back SQL transaction")
                 tx.rollback()
                 return FAILED_UPDATE_RESULT
