@@ -1,13 +1,13 @@
 import json
 import pathlib
-from typing import Callable, Dict, Iterable, List, Optional, TextIO, Tuple, Union
+from typing import Callable, Iterable, Optional, TextIO, Union
 
-import orjson
 import requests
 
 from robotoff.off import generate_json_ocr_url, get_barcode_from_path, split_barcode
-from robotoff.prediction.types import Prediction, PredictionType
+from robotoff.prediction.types import Prediction
 from robotoff.settings import BaseURLProvider
+from robotoff.types import PredictionType
 from robotoff.utils import get_logger, http_session, jsonl_iter, jsonl_iter_fp
 from robotoff.utils.types import JSONType
 
@@ -29,8 +29,8 @@ from .trace import find_traces
 logger = get_logger(__name__)
 
 
-PREDICTION_TYPE_TO_FUNC: Dict[
-    str, Callable[[Union[OCRResult, str]], List[Prediction]]
+PREDICTION_TYPE_TO_FUNC: dict[
+    str, Callable[[Union[OCRResult, str]], list[Prediction]]
 ] = {
     PredictionType.category: find_category,
     PredictionType.packager_code: find_packager_codes,
@@ -79,7 +79,7 @@ def get_ocr_result(
         return None
 
     try:
-        ocr_data: Dict = r.json()
+        ocr_data: dict = r.json()
     except json.JSONDecodeError as e:
         error_message = "Error while decoding OCR JSON"
         if error_raise:
@@ -103,7 +103,7 @@ def extract_predictions(
     prediction_type: PredictionType,
     barcode: Optional[str] = None,
     source_image: Optional[str] = None,
-) -> List[Prediction]:
+) -> list[Prediction]:
     """Extract predictions from OCR using for provided prediction type.
 
     :param content: OCR output to extract predictions from.
@@ -138,7 +138,7 @@ def get_source(
     return "/{}/{}.jpg" "".format("/".join(split_barcode(barcode)), image_name)
 
 
-def ocr_content_iter(items: Iterable[JSONType]) -> Iterable[Tuple[Optional[str], Dict]]:
+def ocr_content_iter(items: Iterable[JSONType]) -> Iterable[tuple[Optional[str], dict]]:
     for item in items:
         if "content" in item:
             source = item["source"].replace("//", "/").replace(".json", ".jpg")
@@ -147,7 +147,7 @@ def ocr_content_iter(items: Iterable[JSONType]) -> Iterable[Tuple[Optional[str],
 
 def ocr_iter(
     source: Union[str, TextIO, pathlib.Path]
-) -> Iterable[Tuple[Optional[str], Dict]]:
+) -> Iterable[tuple[Optional[str], dict]]:
     if isinstance(source, pathlib.Path):
         items = jsonl_iter(source)
         yield from ocr_content_iter(items)
@@ -155,36 +155,3 @@ def ocr_iter(
     elif not isinstance(source, str):
         items = jsonl_iter_fp(source)
         yield from ocr_content_iter(items)
-
-    elif is_barcode(source):
-        barcode: str = source
-        image_data = fetch_images_for_ean(source)["product"]["images"]
-
-        for image_id in image_data.keys():
-            if image_id.isdigit():
-                print("Getting OCR for image {}".format(image_id))
-                data = get_json_for_image(barcode, image_id)
-                source = get_source(image_id, barcode=barcode)
-                if data:
-                    yield source, data
-
-    else:
-        input_path = pathlib.Path(source)
-
-        if not input_path.exists():
-            print("Unrecognized input: {}".format(input_path))
-            return
-
-        if input_path.is_dir():
-            for json_path in input_path.glob("**/*.json"):
-                with open(str(json_path), "rb") as f:
-                    source = get_source(json_path.stem, json_path=str(json_path))
-                    yield source, orjson.loads(f.read())
-        else:
-            if ".json" in input_path.suffixes:
-                with open(str(input_path), "rb") as f:
-                    yield None, orjson.loads(f.read())
-
-            elif ".jsonl" in input_path.suffixes:
-                items = jsonl_iter(input_path)
-                yield from ocr_content_iter(items)
